#!/usr/bin/env bash

function miner_ver() {
  local MINER_VER=$VERTHASHMINER_VER
  [[ -z $MINER_VER ]] && MINER_VER=$MINER_LATEST_VER
  echo $MINER_VER
}

function miner_config_echo() {
  local MINER_VER=`miner_ver`
  miner_echo_config_file "/hive/miners/$MINER_NAME/$MINER_VER/miner.conf"
}

function miner_config_gen() {
  local MINER_CONFIG="$MINER_DIR/$MINER_VER/miner.conf"
  mkfile_from_symlink $MINER_CONFIG

  [[ -z $VERTHASHMINER_TEMPLATE ]] && echo -e "${YELLOW}VERTHASHMINER_TEMPLATE is empty${NOCOLOR}" && return 1
  [[ -z $VERTHASHMINER_URL ]] && echo -e "${YELLOW}VERTHASHMINER_URL is empty${NOCOLOR}" && return 1
  [[ -z $VERTHASHMINER_ALGO ]] && VERTHASHMINER_ALGO='verthash'

  local pool=`head -n 1 <<< "$VERTHASHMINER_URL"`
  [[ ! $pool =~ "stratum+tcp://" ]] && pool="stratum+tcp://$pool"
  local conf="-u $VERTHASHMINER_TEMPLATE -p $VERTHASHMINER_PASS -o $pool --verthash-data $MINER_DIR/$MINER_VER/verthash.dat"

  #add all available devices if no device selected in user config
  if [[ ! $VERTHASHMINER_USER_CONFIG =~ "-d " && ! $VERTHASHMINER_USER_CONFIG =~ "-cl-devices" &&  ! $VERTHASHMINER_USER_CONFIG =~ "-D " && ! $VERTHASHMINER_USER_CONFIG =~ "-cu-devices" ]]; then
    conf+=" --all-cl-devices --all-cu-devices"
  fi
  [[ ! -z $VERTHASHMINER_USER_CONFIG ]] && conf+=" $VERTHASHMINER_USER_CONFIG"

  echo "$conf" > $MINER_CONFIG

  if [[ $VERTHASHMINER_TMPFS -eq 1 ]]; then
    ln -sf $MINER_DIR/tmpfs/verthash.dat $MINER_DIR/$MINER_VER/verthash.dat

    local tmp_dir=$MINER_DIR/tmpfs
    $MINER_DIR/h-umount_tmpfs.sh $MINER_DIR/$MINER_VER/VerthashMiner $tmp_dir

    [[ ! -d $tmp_dir ]] && mkdir -p $tmp_dir
    mount -t tmpfs -o size=1225M tmpfs $tmp_dir

    (crontab -l; echo "*/1 * * * * $MINER_DIR/h-umount_tmpfs.sh $MINER_DIR/$MINER_VER/VerthashMiner $tmp_dir") | crontab -
  else
    ln -sf /home/user/tmp/verthash.dat $MINER_DIR/$MINER_VER/verthash.dat
  fi
}
